@@ -20,9 +20,10 @@
  */
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 
-#include <libwpd-stream/WPXStream.h>
+#include <librevenge-stream/librevenge-stream.h>
 
 #include "libwps_internal.h"
 #include "libwps_tools_win.h"
@@ -31,10 +32,9 @@
 #include "WPSEntry.h"
 #include "WPSHeader.h"
 #include "WPSOLEParser.h"
-#include "WPSOLEStream.h"
 #include "WPSPageSpan.h"
 #include "WPSPosition.h"
-#include "WPSSubDocument.h"
+#include "WPSTextSubDocument.h"
 
 #include "WPS8Graph.h"
 #include "WPS8Struct.h"
@@ -46,21 +46,21 @@
 namespace WPS8ParserInternal
 {
 //! Internal: the subdocument of a WPS8Parser
-class SubDocument : public WPSSubDocument
+class SubDocument : public WPSTextSubDocument
 {
 public:
 	//! type of an entry
 	enum Type { Unknown, TEXT };
 	//! constructor for a text entry
-	SubDocument(WPXInputStreamPtr input, WPS8Parser &pars, WPSEntry const &entry) :
-		WPSSubDocument (input, &pars), m_entry(entry) {}
+	SubDocument(RVNGInputStreamPtr input, WPS8Parser &pars, WPSEntry const &entry) :
+		WPSTextSubDocument(input, &pars), m_entry(entry) {}
 	//! destructor
 	~SubDocument() {}
 
 	//! operator==
-	virtual bool operator==(shared_ptr<WPSSubDocument> const &doc) const
+	virtual bool operator==(shared_ptr<WPSTextSubDocument> const &doc) const
 	{
-		if ( !doc || !WPSSubDocument::operator==(doc))
+		if (!doc || !WPSTextSubDocument::operator==(doc))
 			return false;
 		SubDocument const *sDoc = dynamic_cast<SubDocument const *>(doc.get());
 		if (!sDoc) return false;
@@ -80,13 +80,13 @@ void SubDocument::parse(shared_ptr<WPSContentListener> &listener, libwps::SubDoc
 		WPS_DEBUG_MSG(("WPS8ParserInternal::SubDocument::parse: no listener\n"));
 		return;
 	}
-	if (!dynamic_cast<WPS8ContentListener *>(listener.get()))
+	if (!dynamic_cast<WPSContentListener *>(listener.get()))
 	{
 		WPS_DEBUG_MSG(("WPS8ParserInternal::SubDocument::parse: bad listener\n"));
 		return;
 	}
 
-	WPS8ContentListenerPtr &listen =  static_cast<WPS8ContentListenerPtr &>(listener);
+	WPSContentListenerPtr &listen =  static_cast<WPSContentListenerPtr &>(listener);
 	if (!m_parser)
 	{
 		listen->insertCharacter(' ');
@@ -132,7 +132,7 @@ struct Frame
 	//! constructor
 	Frame() : m_parsed(false), m_type(UNKNOWN), m_pos(),
 		m_idStrs(-1), m_idObject(-1), m_idTable(-1), m_idOle(-1), m_columns(1), m_idBorder(),
-		m_backgroundColor(0xFFFFFF), m_error("")
+		m_backgroundColor(WPSColor::white()), m_error("")
 	{
 		m_pos.setRelativePosition(WPSPosition::Page);
 		m_pos.setPage(1);
@@ -164,7 +164,7 @@ struct Frame
 	//! the border: an entry to some complex border (if sets)
 	WPSEntry m_idBorder;
 	//! the border's color
-	uint32_t m_backgroundColor;
+	WPSColor m_backgroundColor;
 	//! a string used to store the parsing errors
 	std::string m_error;
 };
@@ -172,7 +172,7 @@ struct Frame
 //! operator<< for a Frame
 std::ostream &operator<<(std::ostream &o, Frame const &ft)
 {
-	switch(ft.m_type)
+	switch (ft.m_type)
 	{
 	case Frame::Header:
 		o<< "header";
@@ -201,7 +201,7 @@ std::ostream &operator<<(std::ostream &o, Frame const &ft)
 	o << "),";
 
 	o << ft.m_pos << ",";
-	switch(ft.m_pos.page())
+	switch (ft.m_pos.page())
 	{
 	case -1:
 		o << "allpages,";
@@ -215,8 +215,8 @@ std::ostream &operator<<(std::ostream &o, Frame const &ft)
 	if (ft.m_columns != 1) o << ft.m_columns << "columns,";
 	if (ft.m_idBorder.valid())
 		o << "border='" << ft.m_idBorder.name() << "':" << ft.m_idBorder.id() << ",";
-	if (ft.m_backgroundColor != 0xFFFFFF)
-		o << "backColor=" << std::hex << ft.m_backgroundColor << std::dec << ",";
+	if (!ft.m_backgroundColor.isWhite())
+		o << "backColor=" << ft.m_backgroundColor << ",";
 
 	if (!ft.m_error.empty()) o << "errors=(" << ft.m_error << ")";
 	return o;
@@ -285,12 +285,37 @@ void State::initTypeMaps()
 		m_frameTypes[frameTypes[i]] = frameTypes[i+1];
 
 }
+
+class TableRecursionGuard
+{
+	// disable copying
+	TableRecursionGuard(const TableRecursionGuard &);
+	TableRecursionGuard &operator=(const TableRecursionGuard &);
+
+public:
+	TableRecursionGuard(std::deque<int> &stack, const int id)
+		: m_stack(stack)
+	{
+		m_stack.push_front(id);
+	}
+
+	~TableRecursionGuard()
+	{
+		m_stack.pop_front();
+	}
+
+private:
+	std::deque<int> &m_stack;
+};
+
+
 }
 
 // constructor, destructor
-WPS8Parser::WPS8Parser(WPXInputStreamPtr &input, WPSHeaderPtr &header) :
+WPS8Parser::WPS8Parser(RVNGInputStreamPtr &input, WPSHeaderPtr &header) :
 	WPSParser(input, header),
-	m_listener(), m_graphParser(), m_tableParser(), m_textParser(), m_state()
+	m_listener(), m_graphParser(), m_tableParser(), m_textParser(), m_state(),
+	m_sendingTables()
 {
 	if (version()<5) setVersion(5);
 	m_state.reset(new WPS8ParserInternal::State);
@@ -299,7 +324,7 @@ WPS8Parser::WPS8Parser(WPXInputStreamPtr &input, WPSHeaderPtr &header) :
 	m_textParser.reset(new WPS8Text(*this));
 }
 
-WPS8Parser::~WPS8Parser ()
+WPS8Parser::~WPS8Parser()
 {
 }
 
@@ -323,17 +348,17 @@ bool WPS8Parser::checkInFile(long pos)
 {
 	if (pos <= m_state->m_eof)
 		return true;
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	long actPos = input->tell();
-	input->seek(pos, WPX_SEEK_SET);
+	input->seek(pos, librevenge::RVNG_SEEK_SET);
 	bool ok = input->tell() == pos;
 	if (ok) m_state->m_eof = pos;
-	input->seek(actPos, WPX_SEEK_SET);
+	input->seek(actPos, librevenge::RVNG_SEEK_SET);
 	return ok;
 }
 
 // listener, new page
-void WPS8Parser::setListener(shared_ptr<WPS8ContentListener> listener)
+void WPS8Parser::setListener(shared_ptr<WPSContentListener> listener)
 {
 	m_listener = listener;
 	m_graphParser->setListener(m_listener);
@@ -341,7 +366,7 @@ void WPS8Parser::setListener(shared_ptr<WPS8ContentListener> listener)
 	m_textParser->setListener(m_listener);
 }
 
-shared_ptr<WPS8ContentListener> WPS8Parser::createListener(WPXDocumentInterface *interface)
+shared_ptr<WPSContentListener> WPS8Parser::createListener(librevenge::RVNGTextInterface *interface)
 {
 	std::vector<WPSPageSpan> pageList;
 	WPSPageSpan ps(m_state->m_pageSpan);
@@ -383,8 +408,8 @@ shared_ptr<WPS8ContentListener> WPS8Parser::createListener(WPXDocumentInterface
 	pageList.push_back(ps);
 	for (int i = 1; i < numPages; i++) pageList.push_back(ps);
 	m_state->m_numPages=numPages;
-	return shared_ptr<WPS8ContentListener>
-	       (new WPS8ContentListener(pageList, interface));
+	return shared_ptr<WPSContentListener>
+	       (new WPSContentListener(pageList, interface));
 }
 
 void WPS8Parser::newPage(int number)
@@ -407,10 +432,10 @@ void WPS8Parser::newPage(int number)
 // interface with the graph/text parser
 void WPS8Parser::send(WPSEntry const &entry)
 {
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	long actPos = input->tell();
 	m_textParser->readText(entry);
-	input->seek(actPos, WPX_SEEK_SET);
+	input->seek(actPos, librevenge::RVNG_SEEK_SET);
 }
 
 void WPS8Parser::send(int strsId)
@@ -420,13 +445,13 @@ void WPS8Parser::send(int strsId)
 
 void WPS8Parser::sendTextInCell(int strsId, int cellId)
 {
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	long actPos = input->tell();
 	m_textParser->readTextInCell(strsId,cellId);
-	input->seek(actPos, WPX_SEEK_SET);
+	input->seek(actPos, librevenge::RVNG_SEEK_SET);
 }
 
-void WPS8Parser::sendTextBox(WPSPosition const &pos, int strsid, WPXPropertyList frameExtras)
+void WPS8Parser::sendTextBox(WPSPosition const &pos, int strsid, librevenge::RVNGPropertyList frameExtras)
 {
 	if (!m_listener)
 	{
@@ -450,6 +475,12 @@ bool WPS8Parser::sendObject(Vec2f const &size, int objectId, bool ole)
 
 bool WPS8Parser::sendTable(Vec2f const &size, int objectId)
 {
+	if (find(m_sendingTables.begin(), m_sendingTables.end(), objectId) != m_sendingTables.end())
+	{
+		WPS_DEBUG_MSG(("WPS8Parser::sendTable table %d is contained in itself\n", objectId));
+		return false;
+	}
+
 	std::map<int, int>::iterator pos = m_state->m_object2FrameMap.find(objectId);
 	if (pos == m_state->m_object2FrameMap.end())
 	{
@@ -475,6 +506,7 @@ bool WPS8Parser::sendTable(Vec2f const &size, int objectId)
 		return true;
 	}
 	frame.m_parsed = true;
+	WPS8ParserInternal::TableRecursionGuard guard(m_sendingTables, objectId);
 	return m_tableParser->sendTable(size, frame.m_idTable, frame.m_idStrs);
 }
 
@@ -494,13 +526,13 @@ int WPS8Parser::getTableSTRSId(int tableId) const
 
 ////////////////////////////////////////////////////////////
 // main function to parse the document
-void WPS8Parser::parse(WPXDocumentInterface *documentInterface)
+void WPS8Parser::parse(librevenge::RVNGTextInterface *documentInterface)
 {
-	WPXInputStreamPtr input=getInput();
+	RVNGInputStreamPtr input=getInput();
 	if (!input)
 	{
 		WPS_DEBUG_MSG(("WPS8Parser::parse: does not find main ole\n"));
-		throw(libwps::ParseException());
+		throw (libwps::ParseException());
 	}
 
 	try
@@ -521,13 +553,13 @@ void WPS8Parser::parse(WPXDocumentInterface *documentInterface)
 	catch (...)
 	{
 		WPS_DEBUG_MSG(("WPS8Parser::parse: exception catched when parsing MN0\n"));
-		throw(libwps::ParseException());
+		throw (libwps::ParseException());
 	}
 	setListener(createListener(documentInterface));
 	if (!m_listener)
 	{
 		WPS_DEBUG_MSG(("WPS8Parser::parse: can not create the listener\n"));
-		throw(libwps::ParseException());
+		throw (libwps::ParseException());
 	}
 	m_listener->startDocument();
 	sendPageFrames();
@@ -537,7 +569,7 @@ void WPS8Parser::parse(WPXDocumentInterface *documentInterface)
 	else
 	{
 		WPS_DEBUG_MSG(("WPS8Parser::parse: can not find main text entry\n"));
-		throw(libwps::ParseException());
+		throw (libwps::ParseException());
 	}
 
 #ifdef DEBUG
@@ -559,7 +591,7 @@ bool WPS8Parser::createStructures()
 {
 	if (!getInput()) return false;
 
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	parseHeaderIndex();
 
 	// initialize the text, table, ..
@@ -574,8 +606,7 @@ bool WPS8Parser::createStructures()
 	pos = getNameEntryMap().lower_bound("DOP ");
 	while (getNameEntryMap().end() != pos)
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("DOP ")) break;
 		if (!entry.hasType("DOP ")) continue;
 
@@ -587,8 +618,7 @@ bool WPS8Parser::createStructures()
 	pos = getNameEntryMap().lower_bound("PRNT");
 	while (getNameEntryMap().end() != pos)
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("PRNT")) break;
 		if (!entry.hasType("WNPR")) continue;
 
@@ -599,8 +629,7 @@ bool WPS8Parser::createStructures()
 	pos = getNameEntryMap().lower_bound("SYID");
 	while (getNameEntryMap().end() != pos)
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("SYID")) break;
 		if (!entry.hasType("SYID")) continue;
 
@@ -610,11 +639,11 @@ bool WPS8Parser::createStructures()
 
 	// document title
 	pos = getNameEntryMap().find("TITL");
-	WPXString title;
+	librevenge::RVNGString title;
 	if (getNameEntryMap().end() != pos && pos->second.hasType("TITL"))
 	{
 		pos->second.setParsed(true);
-		input->seek(pos->second.begin(), WPX_SEEK_SET);
+		input->seek(pos->second.begin(), librevenge::RVNG_SEEK_SET);
 		m_textParser->readString(input, pos->second.length(), title);
 		ascii().addPos(pos->second.begin());
 		ascii().addNote(title.cstr());
@@ -624,8 +653,7 @@ bool WPS8Parser::createStructures()
 	pos = getNameEntryMap().lower_bound("FRAM");
 	while (getNameEntryMap().end() != pos)
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("FRAM")) break;
 		if (!entry.hasType("FRAM")) continue;
 
@@ -649,15 +677,14 @@ bool WPS8Parser::createStructures()
 
 bool WPS8Parser::createOLEStructures()
 {
-	if (!getInput()) return false;
+	RVNGInputStreamPtr input=getFileInput();
+	if (!input) return false;
 
-	shared_ptr<libwps::Storage> storage = getHeader()->getOLEStorage();
-	if (!storage) return true;
+	if (!input->isStructured()) return true;
 	WPSOLEParser oleParser("CONTENTS");
-	if (!oleParser.parse(storage)) return false;
+	if (!oleParser.parse(input)) return false;
 
-	m_graphParser->storeObjects(oleParser.getObjects(),oleParser.getObjectsId(),
-	                            oleParser.getObjectsPosition());
+	m_graphParser->storeObjects(oleParser.getObjects(),oleParser.getObjectsId());
 #ifdef DEBUG
 	// there can remain some embedded Works subdocument ( WKS, ... )
 	// with name MN0 and some unknown picture ole
@@ -672,21 +699,21 @@ bool WPS8Parser::createOLEStructures()
 			continue;
 		if (name== "SPELLING")
 		{
-			WPXInputStreamPtr ole = storage->getDocumentOLEStream(name.c_str());
+			RVNGInputStreamPtr ole(input->getSubStreamByName(name.c_str()));
 			if (ole && readSPELLING(ole, name))
 				continue;
 		}
 		WPS_DEBUG_MSG(("WPS8Parser::createOLEStructures:: Find unparsed ole: %s\n", name.c_str()));
 
 #ifdef DEBUG_WITH_FILES
-		WPXInputStreamPtr ole = storage->getDocumentOLEStream(name.c_str());
+		RVNGInputStreamPtr ole(input->getSubStreamByName(name.c_str()));
 		if (!ole.get())
 		{
 			WPS_DEBUG_MSG(("WPS8Parser::createOLEStructures: error: can find OLE part: \"%s\"\n", name.c_str()));
 			continue;
 		}
 
-		WPXBinaryData data;
+		librevenge::RVNGBinaryData data;
 		if (libwps::readDataToEnd(ole,data))
 			libwps::Debug::dumpFile(data, name.c_str());
 #endif
@@ -703,7 +730,7 @@ void WPS8Parser::sendPageFrames()
 	if (!m_listener) return;
 
 	typedef WPS8ParserInternal::Frame Frame;
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	long actPos = input->tell();
 
 	size_t numFrames = m_state->m_frameList.size();
@@ -731,13 +758,9 @@ void WPS8Parser::sendPageFrames()
 			m_graphParser->sendObject(pos, frame.m_idOle, true);
 		else if (frame.m_type == Frame::Text)
 		{
-			WPXPropertyList frameExtras;
-			if (frame.m_backgroundColor != 0xFFFFFF)
-			{
-				char color[20];
-				sprintf(color,"#%06x",frame.m_backgroundColor);
-				frameExtras.insert("fo:background-color", color);
-			}
+			librevenge::RVNGPropertyList frameExtras;
+			if (!frame.m_backgroundColor.isWhite())
+				frameExtras.insert("fo:background-color", frame.m_backgroundColor.str().c_str());
 			sendTextBox(pos, frame.m_idStrs, frameExtras);
 		}
 		else if (frame.m_type != Frame::Header && frame.m_type != Frame::Footer)
@@ -746,14 +769,14 @@ void WPS8Parser::sendPageFrames()
 		}
 	}
 
-	input->seek(actPos,WPX_SEEK_SET);
+	input->seek(actPos,librevenge::RVNG_SEEK_SET);
 }
 
 ////////////////////////////////////////////////////////////
 // read the index
 bool WPS8Parser::parseHeaderIndexEntry()
 {
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	long pos = input->tell();
 	ascii().addPos(pos);
 
@@ -762,20 +785,20 @@ bool WPS8Parser::parseHeaderIndexEntry()
 	uint16_t cch = libwps::readU16(input);
 
 	// check if the entry can be read
-	input->seek(pos + cch, WPX_SEEK_SET);
+	input->seek(pos + cch, librevenge::RVNG_SEEK_SET);
 	if (input->tell() != pos+cch)
 	{
 		WPS_DEBUG_MSG(("WPS8Parser::parseHeaderIndexEntry: error: incomplete entry\n"));
 		ascii().addNote("###IndexEntry incomplete (ignored)");
 		return false;
 	}
-	input->seek(pos + 2, WPX_SEEK_SET);
+	input->seek(pos + 2, librevenge::RVNG_SEEK_SET);
 
 	if (0x18 != cch)
 	{
 		if (cch < 0x18)
 		{
-			input->seek(pos + cch, WPX_SEEK_SET);
+			input->seek(pos + cch, librevenge::RVNG_SEEK_SET);
 			ascii().addNote("###IndexEntry too short(ignored)");
 			if (cch < 10) throw libwps::ParseException();
 			return true;
@@ -793,10 +816,10 @@ bool WPS8Parser::parseHeaderIndexEntry()
 
 		if (c != 0 && c != 0x20 && (41 > c || c > 90))
 		{
-			WPS_DEBUG_MSG(("WPS8Parser::parseHeaderIndexEntry: error: bad character=%u (0x%02x) in name in header index\n", c, c));
+			WPS_DEBUG_MSG(("WPS8Parser::parseHeaderIndexEntry: error: bad character=%u (0x%02x) in name in header index\n", (unsigned)c, (unsigned)c));
 			ascii().addNote("###IndexEntry bad name(ignored)");
 
-			input->seek(pos + cch, WPX_SEEK_SET);
+			input->seek(pos + cch, librevenge::RVNG_SEEK_SET);
 			return true;
 		}
 	}
@@ -813,7 +836,7 @@ bool WPS8Parser::parseHeaderIndexEntry()
 
 	std::string name2;
 	for (i =0; i < 4; i++)
-		name2.append(1, (int) libwps::readU8(input));
+		name2.append(1, (char) libwps::readU8(input));
 	f << "), " << name2;
 
 	WPSEntry hie;
@@ -829,12 +852,12 @@ bool WPS8Parser::parseHeaderIndexEntry()
 	if (cch != 0x18 && parseHeaderIndexEntryEnd(pos+cch, hie, mess))
 		f << "," << mess;
 
-	input->seek(hie.end(), WPX_SEEK_SET);
+	input->seek(hie.end(), librevenge::RVNG_SEEK_SET);
 	if (input->tell() != hie.end())
 	{
 		f << ", ###ignored";
 		ascii().addNote(f.str().c_str());
-		input->seek(pos + cch, WPX_SEEK_SET);
+		input->seek(pos + cch, librevenge::RVNG_SEEK_SET);
 		return true;
 	}
 
@@ -853,7 +876,7 @@ bool WPS8Parser::parseHeaderIndexEntry()
 	ascii().addPos(hie.end());
 	ascii().addNote("_");
 
-	input->seek(pos + cch, WPX_SEEK_SET);
+	input->seek(pos + cch, librevenge::RVNG_SEEK_SET);
 	return true;
 }
 
@@ -862,14 +885,14 @@ bool WPS8Parser::parseHeaderIndexEntry()
 //
 bool WPS8Parser::parseHeaderIndexEntryEnd(long endPos, WPSEntry &hie, std::string &mess)
 {
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 
 	long pos = input->tell();
 	long len = endPos-pos;
 	libwps::DebugStream f;
 
 	int size = (int) libwps::read16(input);
-	WPXString str;
+	librevenge::RVNGString str;
 	if (2*(size+1) != len || !m_textParser->readString(input, 2*size, str))
 	{
 		WPS_DEBUG_MSG(("WPS8Parser::parseHeaderIndexEntryEnd: unknown data\n"));
@@ -892,9 +915,9 @@ bool WPS8Parser::parseHeaderIndexEntryEnd(long endPos, WPSEntry &hie, std::strin
  */
 bool WPS8Parser::parseHeaderIndex()
 {
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	getNameEntryMap().clear();
-	input->seek(0x08, WPX_SEEK_SET);
+	input->seek(0x08, librevenge::RVNG_SEEK_SET);
 
 	long pos = input->tell();
 	int i0 = (int) libwps::read16(input);
@@ -913,11 +936,11 @@ bool WPS8Parser::parseHeaderIndex()
 	ascii().addPos(pos);
 	ascii().addNote(f.str().c_str());
 
-	input->seek(0x18, WPX_SEEK_SET);
+	input->seek(0x18, librevenge::RVNG_SEEK_SET);
 	bool readSome = false;
 	do
 	{
-		if (input->atEOS()) return readSome;
+		if (input->isEnd()) return readSome;
 
 		pos = input->tell();
 		f.str("");
@@ -961,7 +984,7 @@ bool WPS8Parser::parseHeaderIndex()
 
 		if (0xFFFFFFFF == next_index_table)	break;
 
-		if (input->seek(next_index_table, WPX_SEEK_SET) != 0) return readSome;
+		if (input->seek((long) next_index_table, librevenge::RVNG_SEEK_SET) != 0) return readSome;
 	}
 	while (n_entries > 0);
 
@@ -981,7 +1004,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 		return false;
 	}
 
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	page=WPSPageSpan();
 
 	long page_offset = entry.begin();
@@ -990,12 +1013,12 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 
 	if (length < 2)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readDocProperties: warning: DOP length=0x%lx\n", length));
+		WPS_DEBUG_MSG(("WPS8Parser::readDocProperties: warning: DOP length=0x%lx\n", (unsigned long) length));
 		return false;
 	}
 
 	entry.setParsed();
-	input->seek(page_offset, WPX_SEEK_SET);
+	input->seek(page_offset, librevenge::RVNG_SEEK_SET);
 
 	libwps::DebugStream f, f2;
 	if (libwps::read16(input) != length)
@@ -1009,7 +1032,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 	bool readOk = readBlockData(input, endPage,mainData, error);
 
 	size_t numChild = mainData.m_recursData.size();
-	double dim[8];
+	double dim[8] = {0, 0, 0, 0, 0, 0, 0, 0};
 	bool setVal[8] = { false, false, false, false, false, false, false, false};
 	for (size_t c = 0; c < numChild; c++)
 	{
@@ -1045,7 +1068,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 			f2 << "numCols=" << dt.m_value+1 << ",";
 			break;
 		case 0x18:
-			switch(dt.m_value)
+			switch (dt.m_value)
 			{
 			case 1:
 				break; // portrait
@@ -1090,8 +1113,8 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 		case 0x29: // 1 ou 2
 			f2 <<  "f" << dt.id() << "=" << dt.m_value << ",";
 			break;
-			// 0x2a: an integer = 4|6|b
-			// 0x2b: an integer = 0|8|c
+		// 0x2a: an integer = 4|6|b
+		// 0x2b: an integer = 0|8|c
 		case 0x2c:
 		{
 			if (dt.isRead() || !dt.isArray())
@@ -1108,7 +1131,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 			long actPos = input->tell();
 			int numElt = (size-2)/2;
 
-			input->seek(dt.begin()+2, WPX_SEEK_SET);
+			input->seek(dt.begin()+2, librevenge::RVNG_SEEK_SET);
 			std::string str;
 			int elt=0;
 			while (elt < numElt)
@@ -1116,7 +1139,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 				long val = libwps::read16(input);
 				if (val < 30 && val != '\t' && val != '\n')
 				{
-					input->seek(-2, WPX_SEEK_CUR);
+					input->seek(-2, librevenge::RVNG_SEEK_CUR);
 					break;
 				}
 				elt++;
@@ -1125,7 +1148,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 			if (!str.length())
 			{
 				ok = false;
-				input->seek(actPos, WPX_SEEK_SET);
+				input->seek(actPos, librevenge::RVNG_SEEK_SET);
 				break;
 			}
 			f2 << "filename?=["; // wkthmLET.fmt and wkthmSCH.fmt
@@ -1138,7 +1161,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 				if (val) f2 << "f" << elt << "=" << std::hex << val << std::dec << ",";
 			}
 			f2 << "],";
-			input->seek(actPos, WPX_SEEK_SET);
+			input->seek(actPos, librevenge::RVNG_SEEK_SET);
 			break;
 		}
 		case 0x2d:
@@ -1157,7 +1180,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 				break;
 			}
 			long actPos = input->tell();
-			input->seek(dt.begin(), WPX_SEEK_SET);
+			input->seek(dt.begin(), librevenge::RVNG_SEEK_SET);
 			f2 << "unk" << std::hex << dt.id() << "=" << "[";
 			for (int i = 0; i < 128; i++)
 			{
@@ -1165,7 +1188,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 				if (val) f2 << "f" << i << "=" << std::hex << val << std::dec << ",";
 			}
 			f2 << "]" << std::dec << ",";
-			input->seek(actPos, WPX_SEEK_SET);
+			input->seek(actPos, librevenge::RVNG_SEEK_SET);
 			break;
 		}
 
@@ -1243,7 +1266,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 		               entry.name().c_str(), entry.type().c_str()));
 		return false;
 	}
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 
 	long page_offset = entry.begin();
 	long length = entry.length();
@@ -1251,17 +1274,17 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 
 	if (length < 2)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readFRAM warning: length=0x%lx\n", length));
+		WPS_DEBUG_MSG(("WPS8Parser::readFRAM warning: length=0x%lx\n", (unsigned long) length));
 		return false;
 	}
 
 	entry.setParsed();
-	input->seek(page_offset, WPX_SEEK_SET);
+	input->seek(page_offset, librevenge::RVNG_SEEK_SET);
 
 	int numFram = libwps::read16(input);
 	if (numFram < 0 || numFram*2 > length)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readFRAM warning: length=0x%lx, num=%d\n", length, numFram));
+		WPS_DEBUG_MSG(("WPS8Parser::readFRAM warning: length=0x%lx, num=%d\n", (unsigned long) length, numFram));
 		return false;
 	}
 	f << "N=" << numFram;
@@ -1271,7 +1294,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 
 
 	bool parsedAll = true, color = false;
-	long lastPos;
+	long lastPos=input->tell(); // uneeded initialization but makes clang analyser happier
 	for (int i = 0; i < numFram; i++)
 	{
 		lastPos = input->tell();
@@ -1292,10 +1315,10 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 		bool readOk = readBlockData(input, lastPos + sz, mainData, error);
 
 		size_t numChild = mainData.m_recursData.size();
-		double dim[3];
+		double dim[3] = {0, 0, 0};
 		bool setVal[3] = { false, false, false};
 
-		double bDim[4];
+		double bDim[4] = {0, 0, 0, 0};
 		bool bset = false, bsetVal[4] = { false, false, false, false};
 		libwps::DebugStream f2;
 
@@ -1320,7 +1343,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 			}
 			if (dt.id() >= 4 && dt.id() < 11)
 			{
-				switch(dt.id())
+				switch (dt.id())
 				{
 				case 4:
 					minP.setX(float(dt.m_value)/914400.f);
@@ -1359,29 +1382,29 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 				break;
 			}
 			case 1:
-				switch(dt.m_value)
+				switch (dt.m_value)
 				{
-					// associated with 0x13=22:[0|96], 0x18,1b=0x41,0x2e, rarely with 0x1a
+				// associated with 0x13=22:[0|96], 0x18,1b=0x41,0x2e, rarely with 0x1a
 				case 6:
 					frame.m_type = Frame::Header;
 					break;
-					// associated with 0x13=22:[0|96],0x18,1b=0x41,0x2e, rarely with 0x1a
+				// associated with 0x13=22:[0|96],0x18,1b=0x41,0x2e, rarely with 0x1a
 				case 7:
 					frame.m_type = Frame::Footer;
 					break;
 
-					// does the following correspond to page, column, char position ?
+				// does the following correspond to page, column, char position ?
 
-					// associated with 0x11=(m_idOle,0,1), 0x2e=?
+				// associated with 0x11=(m_idOle,0,1), 0x2e=?
 				case 8:
 					frame.m_type = Frame::Object;
 					break;
-					// associated with 0x18=?, 0x46=? and often with a BDR entry
-					// CHECKME: seems also associated to a MCLD, how ?
+				// associated with 0x18=?, 0x46=? and often with a BDR entry
+				// CHECKME: seems also associated to a MCLD, how ?
 				case 9:
 					frame.m_type = Frame::Text;
 					break;
-					// associated with f3 and 0x11=(table_id,0,0) and 0x2a=?
+				// associated with f3 and 0x11=(table_id,0,0) and 0x2a=?
 				case 12:
 					frame.m_type = Frame::Table;
 					break;
@@ -1399,7 +1422,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 			case 0x3: // seem to exist iff type=12
 				if ((frame.m_type == Frame::Table) != dt.isTrue())
 					f2 <<  "isTable?["
-					   <<  (dt.isTrue() ? "true" : "false") << "],";
+					   << (dt.isTrue() ? "true" : "false") << "],";
 				break;
 			case 0x10:   // an entry index always a BDR ?
 				frame.m_idBorder.setName(dt.m_text);
@@ -1421,7 +1444,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 				int numElt = (size-2)/4;
 				long actPos = input->tell();
 
-				input->seek(dt.begin()+2, WPX_SEEK_SET);
+				input->seek(dt.begin()+2, librevenge::RVNG_SEEK_SET);
 				std::vector<long> values;
 				for (int elt = 0; elt < numElt; elt++)
 				{
@@ -1442,7 +1465,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 					f2 << "),";
 				}
 
-				input->seek(actPos, WPX_SEEK_SET);
+				input->seek(actPos, librevenge::RVNG_SEEK_SET);
 				break;
 			}
 			// associated with a tex box and field 0x19
@@ -1480,9 +1503,9 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 			case 0x26: // rotation in degree from center ( CCW)
 				f2 << "rot=" << float(dt.m_value)/10. << "deg,";
 				break;
-				//
-				// Table specific field ?
-				//
+			//
+			// Table specific field ?
+			//
 			case 0x2a:   // link to the m_idTable(ids) number for a table
 			{
 				int id = (int16_t) dt.m_value;
@@ -1511,13 +1534,13 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 				f2 << "f" << dt.id() << "=" << (int16_t) dt.m_value << ",";
 				break;
 
-				// UNKNOWN
+			// UNKNOWN
 			case 0x1a: // appear 2 time (in a header and in a footer) with value 16
-				f2 << "f" << dt.id() << "=" << (int) (int8_t) dt.m_value << ",";
+				f2 << "f" << dt.id() << "=" << (int)(int8_t) dt.m_value << ",";
 				break;
 
 			case 0x2e: // in a table: objectId+1, in textbox: m_idTable ?, other = i ?
-				f2 << "id" << dt.id() << "=" << (int16_t) (dt.m_value-1) << ",";
+				f2 << "id" << dt.id() << "=" << (int16_t)(dt.m_value-1) << ",";
 				break;
 			case 0x13:
 				// table 0x6-??,
@@ -1609,7 +1632,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 // also related to the MCLD ?
 bool WPS8Parser::readSYID(WPSEntry const &entry, std::vector<int> &listId)
 {
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	listId.resize(0);
 	libwps::DebugStream f;
 	if (!entry.hasType(entry.name()))
@@ -1624,15 +1647,15 @@ bool WPS8Parser::readSYID(WPSEntry const &entry, std::vector<int> &listId)
 
 	if (length < 4)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readSYID: warning: SYID length=0x%lx\n", length));
+		WPS_DEBUG_MSG(("WPS8Parser::readSYID: warning: SYID length=0x%lx\n", (unsigned long) length));
 		return false;
 	}
 
-	input->seek(page_offset, WPX_SEEK_SET);
+	input->seek(page_offset, librevenge::RVNG_SEEK_SET);
 
 	int unk = libwps::read32(input);
 	int numID = libwps::read32(input);
-	if (numID < 0 || 4*(numID+2) != length)
+	if (numID < 0 || 4*(long(numID)+2) != length)
 	{
 		WPS_DEBUG_MSG(("WPS8Parser::readSYID: invalid length=%ld, num=%d\n", length, numID));
 		return false;
@@ -1664,19 +1687,19 @@ bool WPS8Parser::readWNPR(WPSEntry const &entry)
 		               entry.name().c_str(), entry.type().c_str()));
 		return false;
 	}
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	long page_offset = entry.begin();
 	long length = entry.length();
 	long endPage = entry.end();
 
 	if (length < 40)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readWNPR: warning: WNPR length=0x%lx\n", length));
+		WPS_DEBUG_MSG(("WPS8Parser::readWNPR: warning: WNPR length=0x%lx\n", (unsigned long) length));
 		return false;
 	}
 
 	entry.setParsed();
-	input->seek(page_offset, WPX_SEEK_SET);
+	input->seek(page_offset, librevenge::RVNG_SEEK_SET);
 
 	libwps::DebugStream f;
 
@@ -1702,7 +1725,7 @@ bool WPS8Parser::readWNPR(WPSEntry const &entry)
 	f << "printmargins?=(";
 	for (int i = 0; i < 4; i++)
 	{
-		long val = libwps::readU32(input);
+		long val = (long) libwps::readU32(input);
 		long sz = dim[2+(i%2)];
 		if (sz)
 			f << float(val)/float(sz) << ",";
@@ -1721,7 +1744,7 @@ bool WPS8Parser::readWNPR(WPSEntry const &entry)
 	long actPos = input->tell();
 	if (actPos + 32*2+38+22 > endPage)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readWNPR: length=0x%lx seems too short\n", length));
+		WPS_DEBUG_MSG(("WPS8Parser::readWNPR: length=0x%lx seems too short\n", (unsigned long) length));
 		return false;
 	}
 
@@ -1811,17 +1834,17 @@ bool WPS8Parser::readWNPR(WPSEntry const &entry)
 //
 ////////////////////////////////////////////////////////////////
 #ifndef DEBUG
-bool WPS8Parser::readSPELLING(WPXInputStreamPtr, std::string const &)
+bool WPS8Parser::readSPELLING(RVNGInputStreamPtr, std::string const &)
 {
 	return true;
 }
 #else
-bool WPS8Parser::readSPELLING(WPXInputStreamPtr input, std::string const &oleName)
+bool WPS8Parser::readSPELLING(RVNGInputStreamPtr input, std::string const &oleName)
 {
 	// SPELLING
-	input->seek(0, WPX_SEEK_SET);
+	input->seek(0, librevenge::RVNG_SEEK_SET);
 	int vers = (int) libwps::read32(input); // always 6 ?
-	if (vers < 0 || input->atEOS()) return false;
+	if (vers < 0 || input->isEnd()) return false;
 
 	std::string fName = libwps::Debug::flattenFileName(oleName);
 	libwps::DebugFile asciiFile(input);
@@ -1833,20 +1856,20 @@ bool WPS8Parser::readSPELLING(WPXInputStreamPtr input, std::string const &oleNam
 
 	libwps::DebugStream f;
 	int num = 0;
-	while(!input->atEOS())
+	while (!input->isEnd())
 	{
 		long pos = input->tell();
 		int numVal = (int) libwps::read32(input);
 
-		if (numVal < 0 || input->seek(8*numVal, WPX_SEEK_CUR) || input->tell() != pos+4+8*numVal)
+		if (numVal < 0 || input->seek(8*numVal, librevenge::RVNG_SEEK_CUR) || input->tell() != pos+4+8*numVal)
 		{
-			input->seek(pos, WPX_SEEK_SET);
+			input->seek(pos, librevenge::RVNG_SEEK_SET);
 			break;
 		}
 
 		f.str("");
 		f << "SPELLING" << num++ << ": "; // linked to STRSj by num = numSTRS-j?
-		input->seek(pos+4, WPX_SEEK_SET);
+		input->seek(pos+4, librevenge::RVNG_SEEK_SET);
 		for (int j = 0; j < numVal; j++)
 		{
 			uint32_t ptr = libwps::readU32(input);
@@ -1868,7 +1891,7 @@ bool WPS8Parser::readSPELLING(WPXInputStreamPtr input, std::string const &oleNam
 	f << "SPELLING:";
 	if (vers != 6) f << "version = " << vers << ", ";
 	f << "list=[";
-	for (std::map<uint32_t, int>::iterator it = listIds.begin(); it != listIds.end(); it++)
+	for (std::map<uint32_t, int>::iterator it = listIds.begin(); it != listIds.end(); ++it)
 	{
 		uint32_t val = it->first;
 		f << "SP" << std::dec << it->second << "(" << (val&0xFF) << ":"
@@ -1881,7 +1904,7 @@ bool WPS8Parser::readSPELLING(WPXInputStreamPtr input, std::string const &oleNam
 	f << "]";
 	asciiFile.addPos(0);
 	asciiFile.addNote(f.str().c_str());
-	if (!input->atEOS())
+	if (!input->isEnd())
 	{
 		asciiFile.addPos(input->tell());
 		asciiFile.addNote("###SPELLING");
