@@ -30,7 +30,7 @@
 #include "WPSEntry.h"
 #include "WPSList.h"
 #include "WPSParagraph.h"
-#include "WPSSubDocument.h"
+#include "WPSTextSubDocument.h"
 
 #include "WPS8.h"
 #include "WPS8Struct.h"
@@ -86,7 +86,7 @@ struct Bookmark
 	//! an index
 	int m_id;
 	//! the field value
-	WPXString m_text;
+	librevenge::RVNGString m_text;
 	//! a string used to store the parsing errors
 	std::string m_error;
 };
@@ -228,7 +228,7 @@ std::ostream &operator<<(std::ostream &o, Object const &obj)
 	case Object::Table:
 		o << "Table";
 		break;
-		// an object store in another Ole: id-> gives a pointer
+	// an object store in another Ole: id-> gives a pointer
 	case Object::Image:
 		o << "Object";
 		break;
@@ -261,7 +261,7 @@ struct Token
 	//! an unknown value
 	int m_unknown;
 	//! the field value
-	WPXString m_text;
+	librevenge::RVNGString m_text;
 	//! a string used to store the parsing errors
 	std::string m_error;
 };
@@ -427,15 +427,15 @@ void State::initTypeMaps()
 }
 
 //! Internal: the subdocument of a WPS8Text
-class SubDocument : public WPSSubDocument
+class SubDocument : public WPSTextSubDocument
 {
 public:
 	//! constructor for a note/endnote entry
-	SubDocument(WPXInputStreamPtr input, WPS8Text &pars, WPSEntry const &entry) :
-		WPSSubDocument(input, 0), m_textParser(&pars), m_entry(entry), m_text("") {}
+	SubDocument(RVNGInputStreamPtr input, WPS8Text &pars, WPSEntry const &entry) :
+		WPSTextSubDocument(input, 0), m_textParser(&pars), m_entry(entry), m_text("") {}
 	//! constructor for a comment entry
-	SubDocument(WPXInputStreamPtr input, WPXString const &text) :
-		WPSSubDocument(input, 0), m_textParser(0), m_entry(), m_text(text) {}
+	SubDocument(RVNGInputStreamPtr input, librevenge::RVNGString const &text) :
+		WPSTextSubDocument(input, 0), m_textParser(0), m_entry(), m_text(text) {}
 
 	//! destructor
 	~SubDocument() {}
@@ -458,7 +458,7 @@ public:
 
 	WPS8Text *m_textParser;
 	WPSEntry m_entry;
-	WPXString m_text;
+	librevenge::RVNGString m_text;
 private:
 	SubDocument(SubDocument const &orig);
 	SubDocument &operator=(SubDocument const &orig);
@@ -471,12 +471,12 @@ void SubDocument::parse(WPSContentListenerPtr &listener, libwps::SubDocumentType
 		WPS_DEBUG_MSG(("SubDocument::parse: no listener\n"));
 		return;
 	}
-	if (!dynamic_cast<WPS8ContentListener *>(listener.get()))
+	if (!dynamic_cast<WPSContentListener *>(listener.get()))
 	{
 		WPS_DEBUG_MSG(("SubDocument::parse: bad listener\n"));
 		return;
 	}
-	WPS8ContentListenerPtr &listen =  reinterpret_cast<WPS8ContentListenerPtr &>(listener);
+	WPSContentListenerPtr &listen =  reinterpret_cast<WPSContentListenerPtr &>(listener);
 
 	if (type==libwps::DOC_COMMENT_ANNOTATION)
 	{
@@ -501,7 +501,7 @@ void SubDocument::parse(WPSContentListenerPtr &listener, libwps::SubDocumentType
 	{
 		WPS_DEBUG_MSG(("SubDocument::parse: find unknown type of document...\n"));
 	}
-	m_input->seek(actPos, WPX_SEEK_SET);
+	m_input->seek(actPos, librevenge::RVNG_SEEK_SET);
 }
 
 }
@@ -518,12 +518,12 @@ WPS8Text::WPS8Text(WPS8Parser &parser) : WPSTextParser(parser, parser.getInput()
 	m_styleParser.reset(new WPS8TextStyle(*this));
 }
 
-WPS8Text::~WPS8Text ()
+WPS8Text::~WPS8Text()
 {
 }
 
 //! sets the listener
-void WPS8Text::setListener(WPS8ContentListenerPtr &listen)
+void WPS8Text::setListener(WPSContentListenerPtr &listen)
 {
 	m_listener = listen;
 	m_styleParser->setListener(listen);
@@ -534,8 +534,8 @@ void WPS8Text::setListener(WPS8ContentListenerPtr &listen)
 int WPS8Text::numPages() const
 {
 	int numPage = 1;
-	m_input->seek(m_textPositions.begin(), WPX_SEEK_SET);
-	while (!m_input->atEOS() && m_input->tell() < m_textPositions.end())
+	m_input->seek(m_textPositions.begin(), librevenge::RVNG_SEEK_SET);
+	while (!m_input->isEnd() && m_input->tell() < m_textPositions.end())
 	{
 		if (libwps::readU16(m_input.get()) == 0x0C) numPage++;
 	}
@@ -561,7 +561,7 @@ bool WPS8Text::readParagraph(long endPos, int &id, std::string &mess)
 ////////////////////////////////////////////////////////////
 WPSEntry WPS8Text::getEntry(int strsId) const
 {
-	if (strsId >= int(m_state->m_textZones.size())) return WPSEntry();
+	if (strsId < 0 || strsId >= int(m_state->m_textZones.size())) return WPSEntry();
 	return m_state->m_textZones[size_t(strsId)];
 }
 
@@ -570,11 +570,11 @@ WPSEntry WPS8Text::getHeaderEntry() const
 	WPSEntry res=m_state->getTextZones(6);
 	if (!res.valid() || res.length() != 2) return res;
 	// check if the zone is empty ie. only a eol
-	WPXInputStreamPtr input = const_cast<WPS8Text *>(this)->getInput();
+	RVNGInputStreamPtr input = const_cast<WPS8Text *>(this)->getInput();
 	long actPos = input->tell();
-	input->seek(res.begin(), WPX_SEEK_SET);
+	input->seek(res.begin(), librevenge::RVNG_SEEK_SET);
 	bool empty = libwps::read16(input) == 0xd;
-	input->seek(actPos, WPX_SEEK_SET);
+	input->seek(actPos, librevenge::RVNG_SEEK_SET);
 	if (empty)
 	{
 		m_state->setParsed(res, true);
@@ -588,11 +588,11 @@ WPSEntry WPS8Text::getFooterEntry() const
 	WPSEntry res=m_state->getTextZones(7);
 	if (!res.valid() || res.length() != 2) return res;
 	// check if the zone is empty ie. only a eol
-	WPXInputStreamPtr input = const_cast<WPS8Text *>(this)->getInput();
+	RVNGInputStreamPtr input = const_cast<WPS8Text *>(this)->getInput();
 	long actPos = input->tell();
-	input->seek(res.begin(), WPX_SEEK_SET);
+	input->seek(res.begin(), librevenge::RVNG_SEEK_SET);
 	bool empty = libwps::read16(input) == 0xd;
-	input->seek(actPos, WPX_SEEK_SET);
+	input->seek(actPos, librevenge::RVNG_SEEK_SET);
 	if (empty)
 	{
 		m_state->setParsed(res, true);
@@ -612,7 +612,11 @@ int WPS8Text::getNumTextZones() const
 }
 int WPS8Text::getTextZoneType(int strsId) const
 {
-	assert(strsId >= 0 && strsId < int(m_state->m_textZones.size()));
+	if (strsId < 0 || strsId >= int(m_state->m_textZones.size()))
+	{
+		WPS_DEBUG_MSG(("WPS8Text::getTextZoneType: call with unkown id=%d\n", strsId));
+		return -1;
+	}
 	return m_state->m_textZones[size_t(strsId)].id();
 }
 
@@ -640,34 +644,32 @@ void WPS8Text::readText(WPSEntry const &entry)
 		WPS_DEBUG_MSG(("WPS8Text::readText: called without listener!!!\n"));
 		return;
 	}
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	m_state->setParsed(entry,true);
 	bool mainZone = entry.id()==1;
-	int numColumns = 1;
 	if (mainZone && mainParser().numColumns() > 1)
 	{
-		numColumns = mainParser().numColumns();
+		int numColumns = mainParser().numColumns();
 		if (m_listener->isSectionOpened())
 			m_listener->closeSection();
 		int w = int(72.0*mainParser().pageWidth()/numColumns);
 		std::vector<int> colSize(size_t(numColumns), w);
-		m_listener->openSection(colSize, WPX_POINT);
+		m_listener->openSection(colSize, librevenge::RVNG_POINT);
 	}
 	int lastCId=-1, lastPId=-1; /* -2: nothing, -1: send default, >= 0: readId */
 	std::vector<DataFOD>::iterator plcIt =	m_FODList.begin();
 	while (plcIt != m_FODList.end() && plcIt->m_pos < entry.begin())
 	{
-		DataFOD const &plc = *plcIt;
+		DataFOD const &plc = *(plcIt++);
 		if (plc.m_type==DataFOD::ATTR_TEXT)
 			lastCId = plc.m_id;
 		else if (plc.m_type==DataFOD::ATTR_PARAG)
 			lastPId = plc.m_id;
-		plcIt++;
 	}
 	int actualPage = 1;
 	WPS8TextStyle::FontData special;
-	input->seek(entry.begin(), WPX_SEEK_SET);
-	while (!input->atEOS())
+	input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
+	while (!input->isEnd())
 	{
 		long pos = input->tell();
 		libwps::DebugStream f;
@@ -675,7 +677,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 		if (pos+1 >= entry.end())
 			break;
 		long finalPos = entry.end();
-		while (plcIt != m_FODList.end())
+		for (; plcIt != m_FODList.end(); ++plcIt)
 		{
 			DataFOD const &plc = *plcIt;
 			if (plc.m_pos < pos)
@@ -689,7 +691,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 					finalPos = plc.m_pos;
 				break;
 			}
-			switch(plc.m_type)
+			switch (plc.m_type)
 			{
 			case DataFOD::ATTR_TEXT:
 			{
@@ -728,7 +730,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 				{
 					if (m_state->m_bookmarkMap.find(pos) == m_state->m_bookmarkMap.end())
 					{
-						WPS_DEBUG_MSG(("WPS8Text::readText: can not find bookmark for pos %lX\n",pos));
+						WPS_DEBUG_MSG(("WPS8Text::readText: can not find bookmark for pos %lX\n",(unsigned long) pos));
 					}
 					else
 					{
@@ -743,7 +745,6 @@ void WPS8Text::readText(WPSEntry const &entry)
 			default:
 				break;
 			}
-			plcIt++;
 		}
 		if (lastCId >= -1)
 		{
@@ -761,7 +762,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 			WPS_DEBUG_MSG(("WPS8Text::readText: ### len is odd\n"));
 			throw libwps::ParseException();
 		}
-		while (!input->atEOS())
+		while (!input->isEnd())
 		{
 			if (input->tell()+1 >= finalPos) break;
 
@@ -818,7 +819,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 					long fPos = input->tell()-2; // the note can be linked, so must retrieve the pos...
 					if (m_state->m_notesMap.find(fPos) == m_state->m_notesMap.end())
 					{
-						WPS_DEBUG_MSG(("WPS8Text::readText can not find notes for position : %lx\n", fPos));
+						WPS_DEBUG_MSG(("WPS8Text::readText can not find notes for position : %lx\n", (unsigned long) fPos));
 						break;
 					}
 					WPS8TextInternal::Notes const &note = *m_state->m_notesMap[fPos];
@@ -842,7 +843,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 							m_listener->insertDateTimeField(format.c_str());
 						else
 						{
-							WPS_DEBUG_MSG(("WPS8Text::readText: unknown date/time format for position : %lX\n", pos));
+							WPS_DEBUG_MSG(("WPS8Text::readText: unknown date/time format for position : %lX\n", (unsigned long) pos));
 						}
 						break;
 					}
@@ -865,7 +866,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 				long objPos = input->tell()-2;
 				if (m_state->m_objectMap.find(objPos) == m_state->m_objectMap.end())
 				{
-					WPS_DEBUG_MSG(("WPSText::readText can not find EOB for position : %lX\n", objPos));
+					WPS_DEBUG_MSG(("WPSText::readText can not find EOB for position : %lX\n", (unsigned long) objPos));
 					break;
 				}
 				WPS8TextInternal::Object const &obj = m_state->m_objectMap.find(objPos)->second;
@@ -875,7 +876,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 					mainParser().sendTable(obj.m_size, obj.m_id);
 				else
 				{
-					WPS_DEBUG_MSG(("WPSText::readText do not know how to send object in position : %lX\n", objPos));
+					WPS_DEBUG_MSG(("WPSText::readText do not know how to send object in position : %lX\n", (unsigned long) objPos));
 				}
 				break;
 			}
@@ -955,8 +956,7 @@ bool WPS8Text::readStructures()
 	pos = nameTable.lower_bound("BMKT");
 	while (pos != nameTable.end())
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("BMKT")) break;
 		if (!entry.hasType("PLC ")) continue;
 
@@ -974,8 +974,7 @@ bool WPS8Text::readStructures()
 	pos = nameTable.lower_bound("FTN ");
 	while (pos != nameTable.end())
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("FTN ")) break;
 		if (!entry.hasType("FTN ")) continue;
 
@@ -984,8 +983,7 @@ bool WPS8Text::readStructures()
 	pos = nameTable.lower_bound("EDN ");
 	while (pos != nameTable.end())
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("EDN ")) break;
 		if (!entry.hasType("EDN ")) continue;
 
@@ -997,8 +995,7 @@ bool WPS8Text::readStructures()
 	pos = nameTable.lower_bound("EOBJ");
 	while (pos != nameTable.end())
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("EOBJ")) break;
 		if (!entry.hasType("PLC ")) continue;
 
@@ -1013,8 +1010,7 @@ bool WPS8Text::readStructures()
 	pos = nameTable.lower_bound("TOKN");
 	while (pos != nameTable.end())
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("TOKN")) break;
 		if (!entry.hasType("PLC ")) continue;
 
@@ -1029,8 +1025,7 @@ bool WPS8Text::readStructures()
 	pos = nameTable.lower_bound("TCD ");
 	while (pos != nameTable.end())
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("TCD ")) break;
 		if (!entry.hasType("PLC ")) continue;
 
@@ -1045,8 +1040,7 @@ bool WPS8Text::readStructures()
 	pos = nameTable.lower_bound("STSH");
 	while (nameTable.end() != pos)
 	{
-		WPSEntry const &entry = pos->second;
-		pos++;
+		WPSEntry const &entry = pos++->second;
 		if (!entry.hasName("STSH")) break;
 		if (!entry.hasType("STSH")) continue;
 
@@ -1064,11 +1058,11 @@ bool WPS8Text::readStructures()
 // basic strings functions:
 ////////////////////////////////////////////////////////////
 /* Read an UTF16 character in LE byte ordering, convert it. Courtesy of glib2 */
-long WPS8Text::readUTF16LE(WPXInputStreamPtr input, long endPos, uint16_t firstC)
+long WPS8Text::readUTF16LE(RVNGInputStreamPtr input, long endPos, uint16_t firstC)
 {
 	if (firstC >= 0xdc00 && firstC < 0xe000)
 	{
-		WPS_DEBUG_MSG(("WPS8Text::readUTF16LE: error: character = %i (0x%X)\n", firstC, firstC));
+		WPS_DEBUG_MSG(("WPS8Text::readUTF16LE: error: character = %i (0x%X)\n", firstC, (unsigned) firstC));
 		return 0xfffd;
 	}
 	if (firstC >= 0xd800 && firstC < 0xdc00)
@@ -1087,24 +1081,24 @@ long WPS8Text::readUTF16LE(WPXInputStreamPtr input, long endPos, uint16_t firstC
 		}
 		else
 		{
-			WPS_DEBUG_MSG(("WPS8Text::readUTF16LE: error: surrogate character = %i (0x%X)\n", firstC, firstC));
+			WPS_DEBUG_MSG(("WPS8Text::readUTF16LE: error: surrogate character = %i (0x%X)\n", firstC, (unsigned) firstC));
 			return 0xfffd;
 		}
 	}
 	/** CHECKME: for Symbol font, we must probably convert 0xF0xx and 0x00xx in a 0x03yy symbol :-~ */
-	if (firstC>=28 ) return firstC;
-	WPS_DEBUG_MSG(("WPS8Text::readUTF16LE: error: character = %i (0x%X)\n", firstC, firstC));
+	if (firstC>=28) return firstC;
+	WPS_DEBUG_MSG(("WPS8Text::readUTF16LE: error: character = %i (0x%X)\n", firstC, (unsigned) firstC));
 	return 0xfffd;
 }
 
-bool WPS8Text::readString(WPXInputStreamPtr input, long page_size,
-                          WPXString &res)
+bool WPS8Text::readString(RVNGInputStreamPtr input, long page_size,
+                          librevenge::RVNGString &res)
 {
 	res = "";
 	long page_offset = input->tell();
 	long endString = page_offset + page_size;
 
-	while (input->tell() < endString-1 && !input->atEOS())
+	while (input->tell() < endString-1 && !input->isEnd())
 	{
 		uint16_t val = libwps::readU16(input);
 		if (!val) break;
@@ -1134,11 +1128,11 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 	}
 
 
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	long debPos = entry.begin();
 	long length = entry.length();
 	long endPos = entry.end();
-	input->seek(debPos, WPX_SEEK_SET);
+	input->seek(debPos, librevenge::RVNG_SEEK_SET);
 
 	long zone = (long) libwps::readU32(input);
 	int numTZones = int(m_state->m_textZones.size());
@@ -1150,7 +1144,7 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 
 	// CHECK ME, it is the number of notes or only an unknow field
 	int nNotes = (int) libwps::read32(input);
-	if (nNotes < 0 || 16+4*(3*nNotes+1) > length)
+	if (nNotes < 0 || 16+4*(3*long(nNotes)+1) > length)
 	{
 		WPS_DEBUG_MSG(("WPS8Text::readNotes: warning: readNotes number=%d\n", nNotes));
 		return false;
@@ -1198,14 +1192,13 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 	ascii().addNote(f2.str().c_str());
 
 	long pos;
-	long val;
 	for (int i = 0; i < nNotes; i++)
 	{
 		pos = input->tell();
 		f.str("");
 		f << entry.name() << i << ":";
 		int type = (int) libwps::read16(input);
-		switch(type)
+		switch (type)
 		{
 		case 0:
 			f << "alpha,";
@@ -1218,7 +1211,7 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 			break;
 		}
 		f << "id=" << libwps::read16(input) << ",";
-		val = (long) libwps::read32(input);
+		long val = (long) libwps::read32(input);
 		if (val != -1) f << "label" << val << ",";
 		ascii().addPos(pos);
 		ascii().addNote(f.str().c_str());
@@ -1280,12 +1273,8 @@ void WPS8Text::createNotesCorrespondance()
 	while (nIt != nMap.end())
 	{
 		Notes &notes = const_cast<Notes &>(*nIt->first);
-		if (nIt->second != 0)
-		{
-			nIt++;
+		if (nIt++->second != 0)
 			continue;
-		}
-		nIt++;
 
 		WPSEntry entry = getEntry(notes.m_zoneCorr);
 		if (entry.id() != 2 && entry.id() != 3)
@@ -1432,7 +1421,7 @@ bool WPS8Text::textZonesDataParser
 ////////////////////////////////////////////////////////////
 bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs)
 {
-	WPXInputStreamPtr input=getInput();
+	RVNGInputStreamPtr input=getInput();
 	typedef WPS8TextInternal::Bookmark Bookmark;
 
 	int numBmkt = int(textPtrs.size())-1;
@@ -1458,7 +1447,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 		if (id < 0 || (id > numBmkt && id > 100))
 		{
 			WPS_DEBUG_MSG(("WPS8Text::bmktEndDataParser: odd index =%d\n", id));
-			input->seek(pos, WPX_SEEK_SET);
+			input->seek(pos, librevenge::RVNG_SEEK_SET);
 			return false;
 		}
 		bmk.m_id = id;
@@ -1471,7 +1460,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 	if (sz1 < 4*numBmkt || pos+1+sz1 > endPage)
 	{
 		WPS_DEBUG_MSG(("WPS8Text::bmktEndDataParser: pb with sz1 =%d\n", sz1));
-		input->seek(pos, WPX_SEEK_SET);
+		input->seek(pos, librevenge::RVNG_SEEK_SET);
 		return false;
 	}
 	f << ", Size(StrZone) = " << sz1;
@@ -1483,7 +1472,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 	f << "BMKT(##unkn):";
 	f << libwps::read32(input) <<",";
 	f << "dim?=" << float(libwps::read32(input))/914400.f <<"," << std::hex;
-	while(input->tell() < endPage-sz1 && !input->atEOS())
+	while (input->tell() < endPage-sz1 && !input->isEnd())
 		f << libwps::read16(input) << ",";
 	f << std::dec;
 	ascii().addNote(f.str().c_str());
@@ -1492,7 +1481,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 	// probably int, dim(*914400), int, short, short
 	// ------ end of problematic part -------------
 
-	input->seek(endPage-sz1, WPX_SEEK_SET);
+	input->seek(endPage-sz1, librevenge::RVNG_SEEK_SET);
 
 	pos = input->tell();
 	ascii().addPos(pos);
@@ -1525,8 +1514,8 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 		if (pos == endPage) f << "_"; // can this happens ?
 		else
 		{
-			input->seek(pos, WPX_SEEK_SET);
-			WPXString val;
+			input->seek(pos, librevenge::RVNG_SEEK_SET);
+			librevenge::RVNGString val;
 			int sz = (int) libwps::readU16(input);
 			if (pos + 2+ 2*sz > endPage || !readString(input, 2*sz, val))
 			{
@@ -1539,7 +1528,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 		ascii().addPos(strPos[i]);
 		ascii().addNote(f.str().c_str());
 	}
-	input->seek(endPage, WPX_SEEK_SET);
+	input->seek(endPage, librevenge::RVNG_SEEK_SET);
 
 	// ok, we store the bookmark and we create the plc and the data fod ...
 	std::vector<DataFOD> fods;
@@ -1547,7 +1536,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 	{
 		if (m_state->m_bookmarkMap.find(textPtrs[t]) != m_state->m_bookmarkMap.end())
 		{
-			WPS_DEBUG_MSG(("WPS8Text::bmktEndDataParser: warning: already a bkmt in position %lx\n", textPtrs[t]));
+			WPS_DEBUG_MSG(("WPS8Text::bmktEndDataParser: warning: already a bkmt in position %lx\n", (unsigned long) textPtrs[t]));
 			continue;
 		}
 		else m_state->m_bookmarkMap[textPtrs[t]] = listBmk[t];
@@ -1658,21 +1647,20 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 	int numTokn = int(textPtrs.size())-1;
 	if (numTokn <= 0) return false;
 
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	libwps::DebugStream f;
 	WPS8TextInternal::Token tokn;
 	std::vector<WPS8TextInternal::Token> listToken;
 
-	long pos = input->tell();
 	for (size_t i = 0; i < size_t(numTokn); i++)
 	{
-		pos = input->tell();
+		long pos = input->tell();
 		if (input->tell() + 2 > endPage) return false;
 
 		int sz = (int) libwps::read16(input);
 		if (sz < 2 || pos+sz > endPage)
 		{
-			input->seek(pos, WPX_SEEK_SET);
+			input->seek(pos, librevenge::RVNG_SEEK_SET);
 			return false;
 		}
 
@@ -1680,7 +1668,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 		std::string error;
 		if (!readBlockData(input, pos+sz, data, error) && data.m_recursData.size() == 0)
 		{
-			input->seek(pos, WPX_SEEK_SET);
+			input->seek(pos, librevenge::RVNG_SEEK_SET);
 			return false;
 		}
 
@@ -1697,7 +1685,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 				f << "###" << dt << ",";
 				continue;
 			}
-			switch(dt.id())
+			switch (dt.id())
 			{
 			case 0: // some unknown flags ? link=0x140, pageNumber=0, unknown(6)=0x400
 				tokn.m_unknown=int(dt.m_value);
@@ -1706,7 +1694,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 				tokn.m_textLength=int(dt.m_value);
 				break;
 			case 2: // -2=link, -5=page number, -6=?
-				switch(dt.m_value)
+				switch (dt.m_value)
 				{
 				case -2:
 					tokn.m_type = WPSContentListener::Link;
@@ -1714,8 +1702,8 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 				case -5:
 					tokn.m_type = WPSContentListener::PageNumber;
 					break;
-					// CHECKME: case -6-> strings = SPC, text character = 0xb7
-					// an insecable character or space ?
+				// CHECKME: case -6-> strings = SPC, text character = 0xb7
+				// an insecable character or space ?
 				default:
 					WPS_DEBUG_MSG(("WPS8Text::tokenEndDataParser: unknown type=%d\n", int(dt.m_value)));
 					f << "###type=" << dt.m_value << ",";
@@ -1744,21 +1732,21 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 	int numFollow = 0;
 	for (int i = 0; i < numTokn; i++)
 	{
-		pos = input->tell();
+		long pos = input->tell();
 		if (input->tell() + 2 > endPage) return false;
 
 		WPS8Struct::FileData data;
 		int sz = (int) libwps::read16(input);
 		if (sz < 2 || pos+sz > endPage)
 		{
-			input->seek(pos, WPX_SEEK_SET);
+			input->seek(pos, librevenge::RVNG_SEEK_SET);
 			return false;
 		}
 
 		std::string error;
 		if (!readBlockData(input, pos+sz, data, error)  && data.m_recursData.size() == 0)
 		{
-			input->seek(pos, WPX_SEEK_SET);
+			input->seek(pos, librevenge::RVNG_SEEK_SET);
 			return false;
 		}
 
@@ -1801,7 +1789,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 	if (numFollow != 0)
 	{
 		// read the strings header
-		pos = input->tell();
+		long pos = input->tell();
 		if (pos+20 > endPage) return false;
 		f.str("");
 		f << "TOKN(strings):";
@@ -1822,7 +1810,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 
 		if (pos+20+4*N > endPage)
 		{
-			input->seek(pos, WPX_SEEK_SET);
+			input->seek(pos, librevenge::RVNG_SEEK_SET);
 			return false;
 		}
 
@@ -1831,13 +1819,13 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 			long val = (long) libwps::read32(input);
 			if (val < 4*N)
 			{
-				input->seek(pos, WPX_SEEK_SET);
+				input->seek(pos, librevenge::RVNG_SEEK_SET);
 				return false;
 			}
 			val += pos+20;
 			if (val > endPage)
 			{
-				input->seek(pos, WPX_SEEK_SET);
+				input->seek(pos, librevenge::RVNG_SEEK_SET);
 				return false;
 			}
 			sPtrs.push_back(val);
@@ -1852,11 +1840,11 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 	size_t numStrings = sPtrs.size();
 	for (size_t i = 0; i < numStrings; i++)
 	{
-		pos = sPtrs[i];
-		input->seek(pos, WPX_SEEK_SET);
+		long pos = sPtrs[i];
+		input->seek(pos, librevenge::RVNG_SEEK_SET);
 		int sz = (int) libwps::read16(input);
 		if (sz < 0 || pos+2*sz+2 > endPage) return false;
-		WPXString str;
+		librevenge::RVNGString str;
 		readString(input, 2*sz, str);
 
 		bool find = false;
@@ -1879,7 +1867,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 	{
 		if (m_state->m_tokenMap.find(textPtrs[t]) != m_state->m_tokenMap.end())
 		{
-			WPS_DEBUG_MSG(("WPS8Text::tokenEndDataParser: warning: already a tokn in position %lx\n", textPtrs[t]));
+			WPS_DEBUG_MSG(("WPS8Text::tokenEndDataParser: warning: already a tokn in position %lx\n", (unsigned long) textPtrs[t]));
 			continue;
 		}
 		else m_state->m_tokenMap[textPtrs[t]] = listToken[t];
@@ -1981,7 +1969,7 @@ bool WPS8Text::readPLC
  std::vector<long> &textPtrs, std::vector<long> &listValues,
  WPS8Text::DataParser parser, WPS8Text::EndDataParser endParser)
 {
-	WPXInputStreamPtr input = getInput();
+	RVNGInputStreamPtr input = getInput();
 	if (!entry.hasType("PLC "))
 	{
 		WPS_DEBUG_MSG(("WPS8Text::readPLC: warning: PLC name=%s, type=%s\n",
@@ -1994,22 +1982,22 @@ bool WPS8Text::readPLC
 	long endPage = entry.end();
 	if (length < 16)
 	{
-		WPS_DEBUG_MSG(("WPS8Text::readPLC: warning: PLC length=0x%lx\n", length));
+		WPS_DEBUG_MSG(("WPS8Text::readPLC: warning: PLC length=0x%lx\n", (unsigned long) length));
 		return false;
 	}
 
-	input->seek(page_offset, WPX_SEEK_SET);
-	int nPLC = (int) libwps::readU32(input);
-	int dataSz = (int) libwps::read32(input);
+	input->seek(page_offset, librevenge::RVNG_SEEK_SET);
+	unsigned nPLC = libwps::readU32(input);
+	unsigned dataSz = libwps::readU32(input);
 	libwps::DebugStream f;
 	f << "PLC: N=" << nPLC << ", dSize=" << dataSz;
 	WPS8PLCInternal::PLC plcType = m_state->m_knownPLC.get(entry.name());
 
-	if (plcType.m_contentType == WPS8PLCInternal::PLC::T_UNKNOWN && 4*nPLC+16 + dataSz *nPLC == length)
+	if (plcType.m_contentType == WPS8PLCInternal::PLC::T_UNKNOWN && long(4ul*nPLC+16 + dataSz *nPLC) == length)
 		plcType.m_contentType = WPS8PLCInternal::PLC::T_CST;
 	else if (plcType.m_contentType == WPS8PLCInternal::PLC::T_CST)
 	{
-		if (4*nPLC+16 + dataSz *nPLC != length)
+		if (long(4ul*nPLC+16 + dataSz *nPLC) != length)
 		{
 			WPS_DEBUG_MSG(("WPS8Text::readPLC: warning: unknown data size\n"));
 			dataSz = 0;
@@ -2018,9 +2006,9 @@ bool WPS8Text::readPLC
 	}
 	else dataSz = 0;
 
-	if (4*nPLC+16 + dataSz*nPLC > length)
+	if (4ul*nPLC+16 + static_cast<unsigned long>(dataSz)*nPLC > static_cast<unsigned long>(length))
 	{
-		WPS_DEBUG_MSG(("WPS8Text::readPLC: warning: PLC length=0x%lx, N=%d\n", length, nPLC));
+		WPS_DEBUG_MSG(("WPS8Text::readPLC: warning: PLC length=0x%lx, N=%u\n", (unsigned long) length, nPLC));
 		return false;
 	}
 	entry.setParsed();
@@ -2052,7 +2040,7 @@ bool WPS8Text::readPLC
 	textPtrs.resize(0);
 	long lastPtr = textZone.begin();
 	f << ",pos = (";
-	for (int i = 0; i <= nPLC; i++)
+	for (unsigned i = 0; i <= nPLC; i++)
 	{
 		long pos = (long) libwps::readU32(input);
 		switch (plcType.m_pos)
@@ -2107,7 +2095,7 @@ bool WPS8Text::readPLC
 		plc.m_type = plcType.m_type;
 		plc.m_name = entry.name();
 		bool printPLC = true;
-		switch(plcType.m_contentType)
+		switch (plcType.m_contentType)
 		{
 		case WPS8PLCInternal::PLC::T_CST :
 		{
@@ -2119,7 +2107,7 @@ bool WPS8Text::readPLC
 			if (dataSz > 4 || dataSz==3)
 			{
 				f2.str("");
-				for (int j = 0; j < dataSz; j++)
+				for (unsigned j = 0; j < dataSz; j++)
 					f2 << std::hex << int(libwps::readU8(input)) << ",";
 				plc.m_error = f2.str();
 			}
@@ -2148,7 +2136,7 @@ bool WPS8Text::readPLC
 			if (parser)
 			{
 				std::string mess;
-				if (!(this->*parser)(textPtrs[i], textPtrs[i+1], int(i), mainData, mess))
+				if (!((i + 1 < textPtrs.size()) && (this->*parser)(textPtrs[i], textPtrs[i+1], int(i), mainData, mess)))
 				{
 					ok = false;
 					break;
@@ -2172,14 +2160,18 @@ bool WPS8Text::readPLC
 			break;
 		}
 
-		fods[i].m_id = (int) m_state->m_plcList.size();
-		if (ok) fods[i].m_defPos = pos;
+		const int plcID = (int) m_state->m_plcList.size();
+		if (i < fods.size())
+		{
+			fods[i].m_id = plcID;
+			if (ok) fods[i].m_defPos = pos;
+		}
 		m_state->m_plcList.push_back(plc);
 
 		if (printPLC)
 		{
 			f2.str("");
-			f2 << plc.m_name << i << "(PLC"<<fods[i].m_id<<"):" << plc;
+			f2 << plc.m_name << i << "(PLC"<<plcID<<"):" << plc;
 			ascii().addPos(pos);
 			ascii().addNote(f2.str().c_str());
 		}
@@ -2197,8 +2189,8 @@ bool WPS8Text::readPLC
 
 	if (ok && endParser)
 	{
-		input->seek(pos, WPX_SEEK_SET);
-		ok = (this->*endParser) (endPage, textPtrs);
+		input->seek(pos, librevenge::RVNG_SEEK_SET);
+		ok = (this->*endParser)(endPage, textPtrs);
 		pos = input->tell();
 		if (pos == endPage) return ok;
 	}
